@@ -8,7 +8,7 @@
 ##' @include paste.row.R
 ##' @noRd
 .initialize <- function (.Object, spc = NULL, data = NULL, wavelength = NULL, labels = NULL){
-  
+
   ## do the small stuff first, so we need not be too careful about copies
 
   ## the wavelength axis
@@ -29,20 +29,20 @@
   else
     nwl <- 0
 
-  
+
   if (is.null (wavelength)){
     ## guess from spc's colnames
     if (!is.null (spc))
       wavelength <- as.numeric (colnames (spc))
-    
+
     if (length (wavelength) == 0L || any (is.na (wavelength)))
       wavelength <- as.numeric (colnames (data$spc))
-    
+
     if (length (wavelength) == 0L || any (is.na (wavelength)))
       wavelength <- seq_len (nwl) # guessing didn't work
-  } 
+  }
   .Object@wavelength <- wavelength
-  
+
   ## column + wavelength axis labels
   if (is.null (labels) || length (labels) == 0L){
     cln <- c (colnames (data), '.wavelength')
@@ -52,9 +52,9 @@
     names (labels) <- cln
     rm (cln)
   }
-  
+
   ## transform labels into expressions
-  .make.expression <- function (x){	
+  .make.expression <- function (x){
     if (is.language (x) && ! is.expression (x))
       class (x) <- "expression"
     else if (is.character (x))
@@ -63,7 +63,7 @@
   }
 
   labels <- lapply (labels, .make.expression)
-  
+
   .Object@label <- labels
 
   rm (labels, wavelength)
@@ -71,17 +71,17 @@
 
   if (! is.null (data$spc) && ! (is.null (spc)))
     warning ("Spectra in data are overwritten by argument spc.")
-  
+
   ## deal with spectra
   if (is.null (spc) && is.null (data$spc)){
     spc <- structure(numeric (0), .Dim = c(0L, 0L))
-  } 
+  }
 
   if (! is.null (spc) && !is.matrix (spc)) {
     spc <- as.matrix (spc)
     if (ncol (spc) == 1L)
         spc <- t (spc)
-  } 
+  }
 
   if (.options$gc) gc ()
 
@@ -89,7 +89,7 @@
     attr (spc, "class") <- "AsIs"       # I seems to make more than one copy
     if (.options$gc) gc ()
   }
-  
+
   ## deal with extra data
   if (is.null (data)){
     data <- data.frame (spc = spc)
@@ -102,7 +102,7 @@
 
   rm (spc)
   if (.options$gc) gc ()
-  
+
   attr (data$spc, "class") <- NULL      # more than one copy!?
   if (.options$gc) gc ()
 
@@ -121,11 +121,11 @@
 ##' Creating a hyperSpec Object
 ##' Like other S4 objects, a hyperSpec object can be created by \code{new}. The
 ##' hyperSpec object is then \code{initialize}d using the given parameters.
-##' 
+##'
 ##' If option \code{gc} is \code{TRUE}, the initialization will have frequent
 ##' calls to \code{gc ()} which can help to avoid swapping or running out of
 ##' memory.
-##' 
+##'
 ##' @name initialize
 ##' @rdname initialize
 ##' @aliases initialize,hyperSpec-method initialize create
@@ -136,11 +136,11 @@
 ##'   \code{data$spc}, and further variates in more columns.  A matrix can be
 ##'   entered as \emph{one} column of a data frame by: \code{data.frame (spc =
 ##'   I (as.matrix (spc)))}.
-##' 
+##'
 ##' However, it will usually be more convenient if the spectra are given in
 ##'   \code{spc}
 ##' @param spc the spectra matrix.
-##' 
+##'
 ##' \code{spc} does not need to be a matrix, it is converted explicitly by
 ##'   \code{I (as.matrix (spc))}.
 ##' @param wavelength The wavelengths corresponding to the columns of
@@ -151,87 +151,179 @@
 ##'   \code{data} slot of the \code{hyperSpec} object and for the wavelength
 ##'   (in \code{label$.wavelength}). The labels should be given in a form ready
 ##'   for the text-drawing functions (see \code{\link[grDevices]{plotmath}}).
-##' 
+##'
 ##' If \code{label} is not given, a list containing \code{NULL} for each of the
 ##'   columns of\code{data} and \code{wavelength} is used.
 ##' @author C.Beleites
 ##' @seealso \code{\link[methods]{new}} for more information on creating and
 ##'   initializing S4 objects.
-##' 
+##'
 ##' \code{\link[grDevices]{plotmath}} on expressions for math annotations as
 ##'   for slot \code{label}.
-##' 
+##'
 ##' \code{\link{hy.setOptions}}
 ##' @keywords methods datagen
 ##' @examples
-##' 
+##'
 ##' new ("hyperSpec")
-##' 
+##'
 ##' spc <- matrix (rnorm (12), ncol = 4)
 ##' new ("hyperSpec", spc = spc)
 ##' new ("hyperSpec", data = data.frame (x = letters[1:3]),
 ##'      spc = spc)
-##' 
+##'
 ##' colnames (spc) <- 600:603
 ##' new ("hyperSpec", spc = spc)  # wavelength taken from colnames (spc)
-##' 
+##'
 ##' # given wavelengths precede over colnames of spc
 ##' new ("hyperSpec", spc = spc, wavelength = 700:703)
-##' 
+##'
 ##' # specifying labels
 ##' h <- new ("hyperSpec", spc = spc, data = data.frame (pos = 1 : 3),
 ##'           label = list (spc = "I / a.u.",
 ##'                         .wavelength = expression (tilde (nu) / cm^-1),
 ##'                         pos = expression ("/" (x, mu*m)))
 ##' )
-##' 
+##'
 ##' plot (h)
 ##' plotc (h, spc ~ pos)
-##' 
+##'
 setMethod ("initialize", "hyperSpec", .initialize)
 
-##' @include hyperspec-package.R
+##' @include unittest.R
 .test (.initialize) <- function (){
+  context (".initialize / new (\"hyperSpec\")")
 
-  checkEqualsNumeric (dim (new ("hyperSpec")), c (0L, 1L, 0L))
+  test_that("empty hyperSpec object", {
+    expect_equivalent (dim (new ("hyperSpec")), c (0L, 1L, 0L))
+  })
 
-  h <- new ("hyperSpec", spc = 1 : 4)
-  checkEqualsNumeric (h@data$spc, 1 : 4)
-  checkEqualsNumeric (dim (h), c (1L, 1L, 4L))
-  checkEqualsNumeric (h@wavelength, 1 : 4)
-  
+  test_that("vector for spc", {
+    h <- new ("hyperSpec", spc = 1 : 4)
+    expect_equal (h@data$spc, matrix (1 : 4, nrow = 1))
+    expect_equivalent (dim (h), c (1L, 1L, 4L))
+    expect_equal (h@wavelength, 1 : 4)
+  })
+
+  test_that("matrix for spc", {
+    spc <- matrix (c(1 : 12), nrow = 3)
+    h <- new ("hyperSpec", spc = spc)
+    expect_equivalent (h@data$spc, spc)
+    expect_equivalent (dim (h), c (3L, 1L, 4L))
+    expect_equal (h@wavelength, 1 : 4)
+  })
 
   spc <- matrix (c(1 : 12), nrow = 3)
-  h <- new ("hyperSpec", spc = spc)
-  checkEqualsNumeric (h@data$spc, spc)
-  checkEqualsNumeric (dim (h), c (3L, 1L, 4L))
-  checkEqualsNumeric (h@wavelength, 1 : 4)
+  test_that("matrix with numbers in colnames for spc", {
+    colnames(spc) <- c(600, 601, 602, 603)
+    h <- new ("hyperSpec", spc = spc)
+    expect_equivalent (h@data$spc, spc)
+    expect_equivalent (dim (h), c (3L, 1L, 4L))
+    expect_equal (h@wavelength, c(600, 601, 602, 603))
+  })
 
   colnames(spc) <- c(600, 601, 602, 603)
-  h <- new ("hyperSpec", spc = spc)
-  checkEqualsNumeric (h@data$spc, spc)
-  checkEqualsNumeric (dim (h), c (3L, 1L, 4L))
-  checkEqualsNumeric (h@wavelength, c(600, 601, 602, 603))
+  test_that("spc and data given", {
+    h <- new ("hyperSpec", spc = spc, data = data.frame (x = 3))
+    expect_equal (h@data$spc, spc)
+    expect_equivalent (dim (h), c (3L, 2L, 4L))
+    expect_equal (h@wavelength, c(600, 601, 602, 603))
+    expect_equal (h@data$x, rep (3, 3L))
+  })
 
-  h <- new ("hyperSpec", spc = spc, data = data.frame (x = 3))
-  checkEqualsNumeric (h@data$spc, spc)
-  checkEqualsNumeric (dim (h), c (3L, 2L, 4L))
-  checkEqualsNumeric (h@wavelength, c(600, 601, 602, 603))
-  checkEqualsNumeric (h@data$x, rep (3, 3L))
+  test_that("spc and data given, data has $spc column (which should be overwritten with warning)", {
+    expect_warning(h <- new ("hyperSpec", spc = spc, data = data.frame (spc = 11:13)))
+    expect_equal (h@data$spc, spc)
+    expect_equivalent (dim (h), c (3L, 1L, 4L))
+    expect_equal (h@wavelength, c(600, 601, 602, 603))
+  })
 
-  h <- new ("hyperSpec", spc = spc, data = data.frame (spc = 11:13))
-  checkEqualsNumeric (h@data$spc, spc)
-  checkEqualsNumeric (dim (h), c (3L, 1L, 4L))
-  checkEqualsNumeric (h@wavelength, c(600, 601, 602, 603))
+  test_that("spc and data given, different numbers of rows", {
+    expect_error (new ("hyperSpec", spc = spc, data = data.frame (x = 11:12)))
+  })
 
-  checkException (new ("hyperSpec", spc = spc, data = data.frame (x = 11:12))) # different number of rows
+  test_that("only data given, data has $spc column with `I()`-protected matrix", {
+    h <- new ("hyperSpec", data = data.frame (spc = I (spc)))
+    expect_equal (h@data$spc, spc)
+    expect_equivalent (dim (h), c (3L, 1L, 4L))
+    expect_equal (h@wavelength, c(600, 601, 602, 603))
+  })
 
-  h <- new ("hyperSpec", data = data.frame (spc = I (spc)))
-  checkEqualsNumeric (h@data$spc, spc)
-  checkEqualsNumeric (dim (h), c (3L, 1L, 4L))
-  checkEqualsNumeric (h@wavelength, c(600, 601, 602, 603))
- 
-  h <- new ("hyperSpec", spc = as.data.frame (spc))
-  checkEqualsNumeric (h@data$spc, spc)
-  checkEqualsNumeric (dim (h), c (3L, 1L, 4L)) 
+  test_that("spc is data.frame", {
+    h <- new ("hyperSpec", spc = as.data.frame (spc))
+    expect_equal (h@data$spc, spc)
+    expect_equivalent (dim (h), c (3L, 1L, 4L))
+  })
+}
+
+
+
+#' as.hyperSpec: convenience conversion functions
+#'
+#' These functions are shortcuts to convert other objects into hypeSpec objects. 
+#'
+#' @param X the object to convert
+#' @param ... additional parameters that should be handed over to \code{new ("hyperSpec")} (initialize)
+#'
+#' @return hyperSpec object
+#' @seealso \code{\link[hyperSpec]{initialize}}
+#' @export
+setGeneric ("as.hyperSpec", 
+            function (X, ...){
+              stop ("as.hyperSpec is not available for objects of class ", class (X))
+            }
+)
+
+#' @include guesswavelength.R
+.as.hyperSpec.matrix <- function (X, wl = guess.wavelength (colnames (X)), ...){
+  new ("hyperSpec", spc = X, wavelength = wl, ...)
+}
+
+#' @rdname as.hyperSpec
+#' @param wl wavelength vector. Defaults to guessing from the column names in \code{X}
+#' @export
+#' 
+#' @examples
+#' tmp <- data.frame(flu [[,, 400 ~ 410]])
+#' (wl <- colnames (tmp))
+#' guess.wavelength (wl)
+
+setMethod ("as.hyperSpec", "matrix", .as.hyperSpec.matrix)
+#' @rdname as.hyperSpec
+setMethod ("as.hyperSpec", "data.frame", .as.hyperSpec.matrix)
+
+##' @include unittest.R
+.test (.as.hyperSpec.matrix) <- function (){
+    context ("as.hyperSpec")
+    
+    spc <- matrix(1:12,ncol = 3)
+    wl <- seq(600, 601, length.out = ncol(spc))
+    
+    test_that("only spc is given", { 
+        expect_identical (new ("hyperSpec", spc = spc), as.hyperSpec(X = spc))
+    })
+    
+    test_that("spc is given as a data.frame", { 
+        expect_equal(new("hyperSpec", spc = as.data.frame(spc),wavelength=1:ncol(spc)), 
+                     as.hyperSpec(X = as.data.frame(spc)))
+    })
+    
+    test_that("spc with characters in colnames", {
+        colnames(spc) <- make.names(wl)
+        h <- as.hyperSpec(X = spc)
+        expect_equal (h@data$spc, spc)
+        expect_equivalent (dim (h), c (nrow(spc), 1L, ncol(spc))) 
+        expect_equal (h@wavelength, wl)
+    })
+    
+    test_that("ignore colnames if wl is set", { 
+        colnames(spc) <- c(601,602,603)
+        expect_identical (new ("hyperSpec", spc = spc, wavelength = wl), as.hyperSpec(X = spc, wl = wl))
+    })
+    
+    test_that("set additional parameters", { 
+        dt <- data.frame(x=1:4,y=letters[1:4])
+        lbs <-  list (spc = "I / a.u.", .wavelength = expression (tilde (nu) / cm^-1))
+        expect_identical (new ("hyperSpec", spc = spc, data = dt, label = lbs), as.hyperSpec(X = spc, data = dt, label = lbs))
+    })
 }
